@@ -1274,7 +1274,7 @@ check_battery_status (TrackerMinerFiles *mf)
 	on_battery = tracker_power_get_on_battery (mf->private->power);
 
 	if (!on_battery) {
-		g_message ("Running on AC power");
+		g_debug ("Running on AC power");
 		should_pause = FALSE;
 		should_throttle = FALSE;
 	} else if (on_low_battery) {
@@ -1290,15 +1290,15 @@ check_battery_status (TrackerMinerFiles *mf)
 				g_message ("Running on battery, but not enabled, pausing");
 				should_pause = TRUE;
 			} else if (tracker_miner_files_get_first_index_done (mf)) {
-				g_message ("Running on battery and first-time index "
-				           "already done, pausing");
+				g_debug ("Running on battery and first-time index "
+				         "already done, pausing");
 				should_pause = TRUE;
 			} else {
-				g_message ("Running on battery, but first-time index not "
-				           "already finished, keeping on");
+				g_debug ("Running on battery, but first-time index not "
+				         "already finished, keeping on");
 			}
 		} else {
-			g_message ("Running on battery");
+			g_debug ("Running on battery");
 		}
 	}
 
@@ -2079,7 +2079,10 @@ miner_files_process_file (TrackerMinerFS      *fs,
 
 	is_directory = (g_file_info_get_file_type (file_info) == G_FILE_TYPE_DIRECTORY ?
 	                TRUE : FALSE);
+
 	modified = g_file_info_get_modification_date_time (file_info);
+	if (!modified)
+		modified = g_date_time_new_from_unix_utc (0);
 
 	if (!create && !is_directory) {
 		/* In case of update: delete all information elements for the given data object
@@ -2200,8 +2203,11 @@ miner_files_process_file_attributes (TrackerMinerFS      *fs,
 		                          NULL, NULL);
 	}
 
-	/* Update nfo:fileLastModified */
 	modified = g_file_info_get_modification_date_time (info);
+	if (!modified)
+		modified = g_date_time_new_from_unix_utc (0);
+
+	/* Update nfo:fileLastModified */
 	time_str = g_date_time_format_iso8601 (modified);
 	tracker_resource_set_string (resource, "nfo:fileLastModified", time_str);
 	g_date_time_unref (modified);
