@@ -136,7 +136,8 @@ guess_dlna_profile (gint          width,
 }
 
 G_MODULE_EXPORT gboolean
-tracker_extract_get_metadata (TrackerExtractInfo *info)
+tracker_extract_get_metadata (TrackerExtractInfo  *info,
+                              GError             **error)
 {
 	struct jpeg_decompress_struct cinfo;
 	struct tej_error_mgr tejerr;
